## $Id: utils.py 16054 2020-04-16 16:17:39Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""General helper functions and utilities for the application section.
"""

from kofacustom.nigeria.applicants.utils import NigeriaApplicantsUtils
from waeup.kofa.applicants.workflow import (INITIALIZED,
    STARTED, PAID, ADMITTED, NOT_ADMITTED, SUBMITTED, CREATED)
from kofacustom.iuokada.interfaces import MessageFactory as _



class ApplicantsUtils(NigeriaApplicantsUtils):
    """A collection of parameters and methods subject to customization.
    """

    ADDITIONAL_FILES = (
                 ('First Sitting Result','fst_sit_scan.pdf'),
                 ('Second Sitting Result','scd_sit_scan.pdf'),
                 ('Higher Qualification Result','hq_scan.pdf'),
                 ('Advanced Level Result','alr_scan.pdf'),
                 ('JAMB Result','jamb.pdf'),
                 ('Statement of Result','res_stat.pdf'),
                 ('NYSC Certificate','nysc.pdf'),
                 )

    APP_TYPES_DICT = {
        'pude': ['Post-UDE Screening', 'PUDE'],
        'sandwich': ['Part-Time Degree in Education', 'SAND'],
        'pt': ['Part-Time Degree Programmes', 'PTP'],
        'putme': ['Post-UTME Screening Exercise', 'PUTME'],
        'app': ['General Studies', 'APP'],
        'ct': ['Certificate Programmes', 'CTP'],
        'dp': ['Diploma Programmes', 'DPP'],
        'pgft': ['Postgraduate Full-Time Programmes', 'PG'],
        'pgpt': ['Postgraduate Part-Time Programmes', 'PG'],
        'pre': ['Pre-Degree Studies', 'PRE'],
        'cbt': ['CBT Practice Test', 'CBT'],
        'ase': ['Admission Screening Exercise', 'ASE'], # successor of putme
        'pg': ['Postgraduate Programmes', 'PG'],
        'ug': ['Undergraduate Programmes', 'UG'],
        }

    SEPARATORS_DICT = {
        'form.applicant_id': _(u'Base Data'),
        'form.course1': _(u'Programmes/Courses Desired'),
        'form.hq_type': _(u'Highest Educational Record (Degrees, Diplomas etc.)'),
        'form.presently': _(u'Course or Programme Presently Attending'),
        'form.nysc_year': _(u'NYSC Information/Exemption Certificate'),
        'form.employer': _(u'Employment History'),
        'form.jamb_subjects': _(u'JAMB Data (All Applicants)'),
        'form.jamb_subjects_list': _(u'JAMB Data (All Applicants)'),
        'form.notice': _(u'Application Process Information'),
        'form.pp_school': _(u'Post Primary School Qualification'),
        'form.presently_inst': _(u'Presently attending a course or programme'),
        'form.fst_sit_fname': _(u'First Sitting Record'),
        'form.scd_sit_fname': _(u'Second Sitting Record'),
        'form.referees': _(u'Referees (will be automatically invited by email after final submission)'),
        'form.parents_name': _(u'Parents / Guardian'),
        }

    def sortCertificates(self, context, resultset):
        """Sort already filtered certificates in `AppCatCertificateSource`.
        """
        resultlist = sorted(resultset, key=lambda
            value: value.__parent__.__parent__.__parent__.code +
            value.__parent__.__parent__.code +
            value.code)
        curr_course = context.course1
        if curr_course is not None and curr_course not in resultlist:
            resultlist = [curr_course,] + resultlist
        return resultlist

    def getCertTitle(self, context, value):
        """Compose the titles in `AppCatCertificateSource`.
        """
        try: title = "%s / %s / %s (%s)" % (
            value.__parent__.__parent__.__parent__.code,
            value.__parent__.__parent__.code,
            value.title, value.code)
        except AttributeError:
            title = "NA / %s (%s)" % (value.title, value.code)
        return title
